.. moban documentation master file, created by
   sphinx-quickstart on Wed Mar 23 18:14:56 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst


Tutorial
==========================================================================================

Please clone the moban repository as the data mentioned in the tutorial are stored in
examples folder.

.. toctree::
   :maxdepth: 1

   level-1-jinja2-cli/README.rst
   level-2-template-inheritance/README.rst
   level-3-data-override/README.rst
   level-4-single-command/README.rst
   level-5-custom-configuration/README.rst
   level-6-complex-configuration/README.rst
   level-7-use-custom-jinja2-filter-test-n-global/README.rst
   level-8-pass-a-folder-full-of-templates/README.rst
   level-9-moban-dependency-as-pypi-package/README.rst
   level-10-moban-dependency-as-git-repo/README.rst
   level-11-use-handlebars/README.rst
   level-12-use-template-engine-extensions/README.rst
   level-13-any-data-override-any-data/README.rst
   level-14-custom-data-loader/README.rst
   level-15-copy-templates-as-target/README.rst
   level-16-group-targets-using-template-type/README.rst
   level-17-force-template-type-from-moban-file/README.rst
   level-18-user-defined-template-types/README.rst
   level-19-moban-a-sub-group-in-targets/README.rst
   level-20-templates-configs-in-zip-or-tar/README.rst
   level-21-copy-templates-into-an-alien-file-system/README.rst
   level-22-intermediate-targets/README.rst
   level-23-inherit-organisational-moban-file/README.rst
   level-24-files-over-http/README.rst
   level-25-delete-intermediate/README.rst


For more complex use case, please look at `its usage in pyexcel project <http://pyexcel.readthedocs.io/en/latest/guide.html>`_

Developer Guide
================================================================================

.. toctree::

   extension

.. include:: ../CHANGELOG.rst

Migration Notes
================================================================================

.. toctree::

   migration-note

   
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
